@@ -34,6 +34,7 @@ from making_with_code_cli.cli_setup import (
     WriteShellConfig,
     InstallPython3,
     InstallGit,
+    InstallTree,
     InstallAtom,
     GHAuthentication,
 )
@@ -46,7 +47,7 @@ from making_with_code_cli.git_backend import (
 
 @click.group()
 def cli():
-    "Command line interface for Making with Code."
+    "Command line interface for Making with Code"
 
 @cli.command()
 def version():
@@ -92,6 +93,7 @@ def setup(ctx, yes, teacher):
         WriteShellConfig(settings),
         InstallPython3(settings),
         InstallGit(settings),
+        InstallTree(settings),
         InstallAtom(settings),
         GHAuthentication(settings),
     ]
@@ -102,7 +104,7 @@ def setup(ctx, yes, teacher):
 
 @cli.command()
 def update():
-    """Update the MWC directory."""
+    """Update the MWC work directory"""
     settings = read_settings()
     curr = get_curriculum(settings)
     course = [c for c in curr['courses'] if c['name'] == settings['course']][0]
